@@ -16,7 +16,7 @@
 
 #include "qhtmlparser.h"
 #include <tidy.h>
-#include <buffio.h>
+#include <tidybuffio.h>
 #include <QIODevice>
 #include <QRegExp>
 
